@@ -13,27 +13,31 @@
 ##############################################################################
 """Test Unauthorized Exception Views"""
 
-from unittest import TestCase, main, makeSuite
-from zope import component, interface
-import zope.browserpage.namedtemplate
-from zope.publisher.browser import TestRequest
-from zope.authentication.interfaces import IAuthentication
-from zope.security.interfaces import IPrincipal
-from zope.app.testing import ztapi
-from zope.app.exception.browser.unauthorized import Unauthorized
-from zope.app.testing.placelesssetup import PlacelessSetup
+import unittest
 
-class DummyPrincipal(object):
-    interface.implements(IPrincipal)  # this is a lie
+import zope.browserpage.namedtemplate
+from zope.authentication.interfaces import IAuthentication
+from zope.component.testing import PlacelessSetup
+from zope.publisher.browser import TestRequest
+from zope.security.interfaces import IPrincipal
+
+from zope import component
+from zope import interface
+from zope.app.exception.browser.unauthorized import Unauthorized
+
+
+@interface.implementer(IPrincipal)  # this is a lie
+class DummyPrincipal:
 
     def __init__(self, id):
         self.id = id
 
-    def getId(self):
+    def getId(self):  # pragma: no cover
         return self.id
 
-class DummyAuthUtility(object):
-    interface.implements(IAuthentication)  # this is a lie
+
+@interface.implementer(IAuthentication)  # this is a lie
+class DummyAuthUtility:
 
     status = None
 
@@ -43,33 +47,34 @@ class DummyAuthUtility(object):
         if self.status is not None:
             self.request.response.setStatus(self.status)
 
-class DummyTemplate(object):
+
+@component.adapter(Unauthorized)
+@interface.implementer(zope.browserpage.namedtemplate.INamedTemplate)
+class DummyTemplate:
 
     def __init__(self, context):
         self.context = context
 
-    component.adapts(Unauthorized)
-    interface.implements(zope.browserpage.namedtemplate.INamedTemplate)
-
     def __call__(self):
         return 'You are not authorized'
 
-class Test(PlacelessSetup, TestCase):
+
+class Test(PlacelessSetup, unittest.TestCase):
 
     def setUp(self):
-        super(Test, self).setUp()
+        super().setUp()
         self.auth = DummyAuthUtility()
-        ztapi.provideUtility(IAuthentication, self.auth)
+        component.provideUtility(self.auth, IAuthentication)
 
     def tearDown(self):
-        super(Test, self).tearDown()
+        super().tearDown()
 
     def testUnauthorized(self):
         component.provideAdapter(DummyTemplate, name="default")
         exception = Exception()
         try:
             raise exception
-        except:
+        except:  # noqa: E722 do not use bare 'except'
             pass
         request = TestRequest()
         request.setPrincipal(DummyPrincipal(23))
@@ -91,14 +96,14 @@ class Test(PlacelessSetup, TestCase):
                          'no-store, no-cache, must-revalidate')
 
         # Make sure the auth utility was called
-        self.failUnless(self.auth.request is request)
+        self.assertIs(self.auth.request, request)
         self.assertEqual(self.auth.principal_id, 23)
 
     def testRedirect(self):
-        exception= Exception()
+        exception = Exception()
         try:
             raise exception
-        except:
+        except:  # noqa: E722 do not use bare 'except'
             pass
         request = TestRequest()
         request.setPrincipal(DummyPrincipal(23))
@@ -109,17 +114,15 @@ class Test(PlacelessSetup, TestCase):
         res = u()
 
         # Make sure that the template was not rendered
-        self.assert_(res is None)
+        self.assertIsNone(res)
 
         # Make sure the auth's redirect is honored
         self.assertEqual(request.response.getStatus(), 303)
 
         # Make sure the auth utility was called
-        self.failUnless(self.auth.request is request)
+        self.assertIs(self.auth.request, request)
         self.assertEqual(self.auth.principal_id, 23)
 
-def test_suite():
-    return makeSuite(Test)
 
-if __name__=='__main__':
-    main(defaultTest='test_suite')
+def test_suite():
+    return unittest.defaultTestLoader.loadTestsFromName(__name__)
