@@ -1,7 +1,7 @@
 ##############################################################################
 # Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
@@ -11,9 +11,8 @@
 ##############################################################################
 """Support for user views"""
 
-class UserErrorView(object):
+
+class UserErrorView:
 
     def title(self):
         return self.context.__class__.__name__
-
-    
